@@ -37,62 +37,82 @@
  */
 
 
-#include "../../config.h"
+#include "config.h"
 
-#include "history.h"
 #include "callbacks.h"
 #include "ekiga.h"
 #include "main.h"
 #include "misc.h"
-#include "urlhandler.h"
 
 #include "gmentrydialog.h"
 #include "gmconf.h"
 #include "gmdialog.h"
 #include "gmconnectbutton.h"
 #include "gmmenuaddon.h"
+#include "gmstockicons.h"
 
 #ifdef WIN32
-#include "winpaths.h"
+#include "platform/winpaths.h"
 #include <shellapi.h>
 #define WIN32_HELP_DIR "help"
 #define WIN32_HELP_FILE "index.html"
 #endif
 
+#ifdef HAVE_GNOME
+#undef _
+#undef N_
+#include <gnome.h>
+#include <libbonobo.h>
+#endif
+
+
 /* The callbacks */
-void
-save_callback (GtkWidget *widget,
-	       gpointer data)
-{
-  GnomeMeeting::Process ()->GetManager ()->SavePicture ();
-}
-
-
-
 gboolean
 delete_window_cb (GtkWidget *widget,
-                  GdkEvent *event,
-                  gpointer data)
+                  G_GNUC_UNUSED GdkEvent *event,
+                  G_GNUC_UNUSED gpointer data)
 {
   gnomemeeting_window_hide (GTK_WIDGET (widget));
 
   return TRUE;
 }
 
+static void
+show_window (GtkWidget *window)
+{
+  if (!gnomemeeting_window_is_visible (window))
+    gnomemeeting_window_show (window);
+  else
+    gtk_window_present (GTK_WINDOW (window));
+}
 
 void
-show_window_cb (GtkWidget *widget,
+show_window_cb (G_GNUC_UNUSED GtkWidget *widget,
 		gpointer data)
 {
-  if (!gnomemeeting_window_is_visible (GTK_WIDGET (data)))
-    gnomemeeting_window_show (GTK_WIDGET (data));
-  else
-    gtk_window_present (GTK_WINDOW (data));
+  show_window (GTK_WIDGET (data));
 }
 
 
 void
-hide_window_cb (GtkWidget *widget,
+show_assistant_window_cb (G_GNUC_UNUSED GtkWidget *widget,
+                          G_GNUC_UNUSED gpointer data)
+{
+  GtkWidget *window = GnomeMeeting::Process ()->GetAssistantWindow ();
+  show_window (window);
+}
+
+void
+show_prefs_window_cb (G_GNUC_UNUSED GtkWidget *widget,
+                      G_GNUC_UNUSED gpointer data)
+{
+  GtkWidget *window = GnomeMeeting::Process ()->GetPrefsWindow ();
+  show_window (window);
+}
+
+
+void
+hide_window_cb (G_GNUC_UNUSED GtkWidget *widget,
 		gpointer data)
 {
   if (gnomemeeting_window_is_visible (GTK_WIDGET (data)))
@@ -101,51 +121,26 @@ hide_window_cb (GtkWidget *widget,
 
 
 void
-connect_cb (GtkWidget *widget,
-	    gpointer data)
-{	
-  PString url;
-
-  g_return_if_fail (data != NULL);
-  
-  url = gm_main_window_get_call_url (GTK_WIDGET (data)); 
-
-  GnomeMeeting::Process ()->Connect (url);
-}
-
-
-void
-disconnect_cb (GtkWidget *widget,
-	       gpointer data)
-{	
-  GtkWidget *main_window = NULL;
-
-  main_window = GnomeMeeting::Process ()->GetMainWindow ();
-  gm_main_window_push_message (main_window, _("Disconnecting..."));
-
-  gdk_threads_leave ();
-  GnomeMeeting::Process ()->Disconnect ();
-  gdk_threads_enter ();
-}
-
-
-void
-about_callback (GtkWidget *widget, 
+about_callback (G_GNUC_UNUSED GtkWidget *widget, 
 		gpointer parent_window)
 {
   const gchar *authors [] = {
       "Damien Sandras <dsandras@seconix.com>",
       "",
       N_("Contributors:"),
+      "Yannick Defais <sevmek@free.fr>",
       "Kilian Krause <kk@verfaction.de>", 
+      "Vincent Luba <luba@novacom.be>",
       "Julien Puydt <julien.puydt@laposte.net>",
       "Luc Saillard <luc@saillard.org>",
       "Jan Schampera <jan.schampera@web.de>",
+      "Matthias Schneider <ma30002000@yahoo.de>",
       "Craig Southeren <craigs@postincrement.com>",
       "",
       N_("Artwork:"),
       "Andreas Kwiatkowski <post@kwiat.org>",
       "Fabian Deutsch <fabian.deutsch@gmx.de>",
+      "Andreas Nilsson <nisses.mail@home.se>",
       "Carlos Pardo <me@m4de.com>",
       "Jakub Steiner <jimmac@ximian.com>",
       "",
@@ -154,8 +149,8 @@ about_callback (GtkWidget *widget,
   };
 	
   authors [2] = gettext (authors [2]);
-  authors [9] = gettext (authors [9]);
-  authors [15] = gettext (authors [15]);
+  authors [10] = gettext (authors [10]);
+  authors [17] = gettext (authors [17]);
   
   const gchar *documenters [] = {
     "Damien Sandras <dsandras@seconix.com>",
@@ -164,26 +159,27 @@ about_callback (GtkWidget *widget,
     NULL
   };
 
-  const gchar *license = "\
-This program is free software; you can redistribute it and/or modify \
+  const gchar *license[] = {
+N_("This program is free software; you can redistribute it and/or modify \
 it under the terms of the GNU General Public License as published by \
 the Free Software Foundation; either version 2 of the License, or \
-(at your option) any later version. \
-\n\n\
-This program is distributed in the hope that it will be useful, \
+(at your option) any later version. "),
+N_("This program is distributed in the hope that it will be useful, \
 but WITHOUT ANY WARRANTY; without even the implied warranty of \
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the \
 GNU General Public License for more details. \
 You should have received a copy of the GNU General Public License \
 along with this program; if not, write to the Free Software Foundation, \
-Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA. \
-\n\n\
-Ekiga is licensed under the GPL license and as a special exception, \
+Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA."),
+N_("Ekiga is licensed under the GPL license and as a special exception, \
 you have permission to link or otherwise combine this program with the \
 programs OPAL, OpenH323 and PWLIB, and distribute the combination, \
 without applying the requirements of the GNU GPL to the OPAL, OpenH323 \
 and PWLIB programs, as long as you do follow the requirements of the \
-GNU GPL for all the rest of the software thus combined.";
+GNU GPL for all the rest of the software thus combined.")
+  };
+
+  gchar *license_trans;
 
   /* Translators: Please write translator credits here, and
    * separate names with \n */
@@ -194,27 +190,32 @@ GNU GPL for all the rest of the software thus combined.";
  
   const gchar *comments =  _("Ekiga is full-featured SIP and H.323 compatible VoIP, IP-Telephony and Videoconferencing application that allows you to make audio and video calls to remote users with SIP and H.323 hardware or software.");
  
+  license_trans = g_strconcat (_(license[0]), "\n\n", _(license[1]), "\n\n",
+                               _(license[2]), "\n\n", NULL);
+
   gtk_show_about_dialog (GTK_WINDOW (parent_window),
 		"name", "Ekiga",
 		"version", VERSION,
-		"copyright", "Copyright © 2000-2007 Damien Sandras",
+		"copyright", "Copyright © 2000-2008 Damien Sandras",
 		"authors", authors,
 		"documenters", documenters,
 		"translator-credits", translator_credits,
 		"comments", comments,
-		"logo-icon-name", PACKAGE_NAME,
-		"license", license,
+		"logo-icon-name", GM_ICON_LOGO,
+		"license", license_trans,
 		"wrap-license", TRUE,
 		"website", "http://www.ekiga.org",
 		NULL);
+
+  g_free (license_trans);
 }
 
 
 void
-help_cb (GtkWidget *widget,
-	 gpointer data)
+help_cb (G_GNUC_UNUSED GtkWidget *widget,
+	 G_GNUC_UNUSED gpointer data)
 {
-#ifndef DISABLE_GNOME
+#ifdef HAVE_GNOME
   GError *err = NULL;
   gnome_help_display (PACKAGE_NAME ".xml", NULL, &err);
 #else
@@ -259,163 +260,30 @@ help_cb (GtkWidget *widget,
 
 
 void
-quit_callback (GtkWidget *widget, 
-	       gpointer data)
+quit_callback (G_GNUC_UNUSED GtkWidget *widget, 
+	       G_GNUC_UNUSED gpointer data)
 {
   GtkWidget *main_window = NULL;
+  GtkWidget *assistant_window = NULL;
   GtkWidget *prefs_window = NULL;
   GtkWidget *accounts_window = NULL;
-  GtkWidget *addressbook_window = NULL;
-  GtkWidget *calls_history_window = NULL;
-  GtkWidget *history_window = NULL;
-  
+
   main_window = GnomeMeeting::Process ()->GetMainWindow ();
-  addressbook_window = GnomeMeeting::Process ()->GetAddressbookWindow ();
-  calls_history_window = GnomeMeeting::Process ()->GetCallsHistoryWindow ();
-  prefs_window = GnomeMeeting::Process ()->GetPrefsWindow ();
+  assistant_window = GnomeMeeting::Process ()->GetAssistantWindow (false);
+  prefs_window = GnomeMeeting::Process ()->GetPrefsWindow (false);
   accounts_window = GnomeMeeting::Process ()->GetAccountsWindow ();
-  history_window = GnomeMeeting::Process ()->GetHistoryWindow ();
   
   gnomemeeting_window_hide (main_window);
-  gnomemeeting_window_hide (history_window);
-  gnomemeeting_window_hide (calls_history_window);
-  gnomemeeting_window_hide (addressbook_window);
-  gnomemeeting_window_hide (prefs_window);
+  if (assistant_window)
+    gnomemeeting_window_hide (assistant_window);
+  if (prefs_window)
+    gnomemeeting_window_hide (prefs_window);
   gnomemeeting_window_hide (accounts_window);
 
+  while (gtk_events_pending ())
+    gtk_main_iteration ();
+
   gtk_main_quit ();
 }  
 
 
-gboolean 
-entry_completion_url_match_cb (GtkEntryCompletion *completion,
-			       const gchar *key,
-			       GtkTreeIter *iter,
-			       gpointer data)
-{
-  GtkListStore *list_store = NULL;
-  GtkTreeIter tree_iter;
-  
-  GtkTreePath *current_path = NULL;
-  GtkTreePath *path = NULL;
-    
-  gchar *val = NULL;
-  gchar *entry = NULL;
-  gchar *tmp_entry = NULL;
-  
-  PCaselessString s;
-
-  PINDEX j = 0;
-  BOOL found = FALSE;
-  
-  g_return_val_if_fail (data != NULL, FALSE);
-  
-  list_store = GTK_LIST_STORE (data);
-
-  if (!key || GMURL (key).GetCanonicalURL ().GetLength () < 2)
-    return FALSE;
-
-  for (int i = 0 ; (i < 2 && !found) ; i++) {
-    
-    gtk_tree_model_get (GTK_TREE_MODEL (list_store), iter, i, &val, -1);
-    s = val;
-    /* Check if one of the names matches the canonical form of the URL */
-    if (i == 0) {
-      
-      j = s.Find (GMURL (key).GetCanonicalURL ());
-
-      if (j != P_MAX_INDEX && j > 0) {
-
-	char c = s [j - 1];
-	
-	found = (c == 32);
-      }
-      else if (j == 0)
-	found = TRUE;
-      else
-	found = FALSE;
-    }
-    /* Check if both GMURLs match */
-    else if (i == 1 && GMURL(s).Find (GMURL (key))) 
-      found = TRUE;
-
-    g_free (val);
-  }
-  
-  if (!found)
-    return FALSE;
-  
-  /* We have found something, but is it the first item ? */
-  gtk_tree_model_get (GTK_TREE_MODEL (list_store), iter, 2, &entry, -1);
-
-  if (found) {
-
-    if (gtk_tree_model_get_iter_first (GTK_TREE_MODEL (list_store),
-				       &tree_iter)) {
-
-      do {
-
-	gtk_tree_model_get (GTK_TREE_MODEL (list_store), &tree_iter, 
-			    2, &tmp_entry, -1);
-
-	if (tmp_entry && !strcmp (tmp_entry, entry)) {
-
-	  current_path = 
-	    gtk_tree_model_get_path (GTK_TREE_MODEL (list_store),
-				     iter);
-	  path = 
-	    gtk_tree_model_get_path (GTK_TREE_MODEL (list_store), 
-				     &tree_iter);
-
-	  if (gtk_tree_path_compare (path, current_path) < 0) 
-	    found = FALSE;
-
-	  gtk_tree_path_free (path);
-	  gtk_tree_path_free (current_path);
-	}
-
-	g_free (tmp_entry);
-	
-      } while (gtk_tree_model_iter_next (GTK_TREE_MODEL (list_store), 
-					 &tree_iter) && found);
-
-    }
-  }
-  
-  g_free (entry);
-
-  return found;
-}
-
-
-void 
-connect_button_clicked_cb (GtkToggleButton *widget, 
-			   gpointer data)
-{
-  GMManager *ep = NULL;
-  PString url;
-
-  g_return_if_fail (data != NULL);
-
-  url = gtk_entry_get_text (GTK_ENTRY (data));
-  ep = GnomeMeeting::Process ()->GetManager ();
-  
-  /* Button is in disconnected state */
-  if (!gm_connect_button_get_connected (GM_CONNECT_BUTTON (widget))
-      && ep->GetCallingState () == GMManager::Standby) {
-      
-    if (!GMURL (url).IsEmpty ())
-      GnomeMeeting::Process ()->Connect (url);
-    else
-      gm_connect_button_set_connected (GM_CONNECT_BUTTON (widget), FALSE);
-  }
-  else if (gm_connect_button_get_connected (GM_CONNECT_BUTTON (widget))
-	   && ep->GetCallingState () != GMManager::Standby) {
-
-    gdk_threads_leave();
-    GnomeMeeting::Process ()->Disconnect ();
-    gdk_threads_enter();
-  }
-  else 
-    gm_connect_button_set_connected (GM_CONNECT_BUTTON (widget), FALSE);
-}
